
# TStickers Tutorials and User Guides

Welcome to the TStickers tutorials. This section provides a handful of tutorials
to help you get started with TStickers and make the most of its features.

## Resource Table

| Guide                 | Description         | Link                                  |
|-----------------------|---------------------|---------------------------------------|
| **getting-started.md** | This guide will walk you through the initial setup of TStickers, including installation and basic usage.  | [View getting-started.md](./getting-started.md) |
| **backends.md**       | Learn about the different backend options available with TStickers.  | [View backends.md](./backends.md)       |
